function [A,b] = collCoeffs(c)
% COLLCOEFFS Calculate the coefficients of RK-collocation methods.
%
%   [A,b] = COLLCOEFFS(C) given the collocation points in the vector C,
%   calculates the matrix A and vector b from the Butcher Table of the
%   corresponding Collocation Method.
%  
% Example Usage: Calculate the Butcher Table of the Implicit Trapezoidal Rule
% (collocation points c1=0, c2=1):
% [A,b] = collCoeffs([0 1])

% Find number of sampling points
s = length(c);

% Find coefficients of the Lagrange polynomial
alpha = inv(vander(c));

% Reserve storage
A = zeros(s);
b = zeros(s, 1);

% loop over all sampling points
for j = 1:s
	
	% Coefficients of an antiderivative of the jth Langrange polynomial
	Lint = polyint(alpha(:, j).');
	
	% evaluate formulas for coefficients
	A(:,j) = polyval(Lint, c);
	b(j) = polyval(Lint, 1);
end